@@ -9,7 +9,7 @@ use strict;
 
 use Lemonldap::NG::Handler::SharedConf qw(:all);
 
-our $VERSION = '0.2';
+our $VERSION = '1.0.0';
 
 use base qw(Lemonldap::NG::Handler::SharedConf);
 
@@ -19,6 +19,7 @@ use base qw(Lemonldap::NG::Handler::SharedConf);
 # @return Apache constant
 sub run ($$) {
     my $class;
+    ( $class, $apacheRequest ) = splice @_;
     $cda = 1;
     return $class->SUPER::run($apacheRequest);
 }
@@ -28,6 +29,8 @@ __END__
 
 =head1 NAME
 
+=encoding utf8
+
 Lemonldap::NG::Handler::CDA - Module to use Lemonldap::NG::Handler
 mechanisms with Cross-Domain-Authentication.
 
@@ -89,7 +92,7 @@ Same as L<Lemonldap::NG::Handler::SharedConf>.
 
 L<Lemonldap::NG::Manager>, L<Lemonldap::NG::Handler>,
 L<Lemonldap::NG::Handler::SharedConf>,
-http://wiki.lemonldap.objectweb.org/xwiki/bin/view/NG/Presentation
+L<http://lemonldap-ng.org/>
 
 =head1 AUTHOR
 
@@ -98,7 +101,7 @@ Xavier Guimard, E<lt>x.guimard@free.frE<gt>
 =head1 BUG REPORT
 
 Use OW2 system to report bug or ask for features:
-L<http://forge.objectweb.org/tracker/?group_id=274>
+L<http://jira.ow2.org>
 
 =head1 DOWNLOAD
 
@@ -107,10 +110,10 @@ L<http://forge.objectweb.org/project/showfiles.php?group_id=274>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2007 by Xavier Guimard E<lt>x.guimard@free.frE<gt>
+Copyright (C) 2007, 2010 by Xavier Guimard E<lt>x.guimard@free.frE<gt>
 
 This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.8.4 or,
+it under the same terms as Perl itself, either Perl version 5.10.0 or,
 at your option, any later version of Perl 5 you may have available.
 
 =cut
