@@ -19,12 +19,15 @@ use strict;
 
 use Lemonldap::NG::Handler::Simple qw(:all);
 use Lemonldap::NG::Handler::Vhost;
-use Lemonldap::NG::Common::Conf;
+use Lemonldap::NG::Common::Conf;               #link protected lmConf
+use Lemonldap::NG::Common::Conf::Constants;    #inherits
 use Cache::Cache qw($EXPIRES_NEVER);
 
 use base qw(Lemonldap::NG::Handler::Vhost Lemonldap::NG::Handler::Simple);
 
-our $VERSION    = '0.7';
+#parameter reloadTime Time in second between 2 configuration check (600)
+
+our $VERSION    = '1.1.1';
 our $cfgNum     = 0;
 our $lastReload = 0;
 our $reloadTime;
@@ -59,9 +62,10 @@ BEGIN {
 # init is overloaded to call only localInit. globalInit is called later.
 # @param $args hash containing parameters
 sub init($$) {
-    my ( $class, $args ) = @_;
+    my ( $class, $args ) = splice @_;
+
+    # TODO reloadTime in defaultValuesInit ?
     $reloadTime = $args->{reloadTime} || 600;
-    $localConfig = $args;
     $class->localInit($args);
 }
 
@@ -70,7 +74,7 @@ sub init($$) {
 # @param $args hash containing parameters
 # @return boolean
 sub defaultValuesInit {
-    my ( $class, $args ) = @_;
+    my ( $class, $args ) = splice @_;
 
     # Local configuration overrides global configuration
     my %h = ( %$args, %$localConfig );
@@ -81,15 +85,28 @@ sub defaultValuesInit {
 # Load parameters and build the Lemonldap::NG::Common::Conf object.
 # @return boolean
 sub localInit {
-    my ( $class, $args ) = @_;
-    die("$class : unable to build configuration : $Lemonldap::NG::Common::Conf::msg")
-        unless($lmConf = Lemonldap::NG::Common::Conf->new( $args->{configStorage} ));
+    my ( $class, $args ) = splice @_;
+    die(
+"$class : unable to build configuration : $Lemonldap::NG::Common::Conf::msg"
+      )
+      unless ( $lmConf =
+        Lemonldap::NG::Common::Conf->new( $args->{configStorage} ) );
+
+    # Get local configuration parameters
+    my $localconf = $lmConf->getLocalConf(HANDLERSECTION);
+    if ($localconf) {
+        $args->{$_} ||= $localconf->{$_} foreach ( keys %$localconf );
+    }
+
+    # Store in localConfig global variable
+    $localConfig = $args;
 
     # localStorage can be declared in configStorage or at the root or both
     foreach (qw(localStorage localStorageOptions)) {
         $args->{$_} ||= $args->{configStorage}->{$_} || $lmConf->{$_};
         $args->{configStorage}->{$_} ||= $args->{$_};
     }
+
     $class->defaultValuesInit($args);
     $class->SUPER::localInit($args);
 }
@@ -103,12 +120,10 @@ sub localInit {
 # @param $r Apache2::RequestRec object
 # @return Apache constant
 sub run($$) {
-    my ( $class, $r ) = @_;
+    my ( $class, $r ) = splice @_;
     if ( time() - $lastReload > $reloadTime ) {
-        unless ( my $tmp = $class->testConf(1) == OK ) {
-            $class->lmLog( "$class: No configuration found", 'error' );
-            return $tmp;
-        }
+        die("$class: No configuration found")
+          unless ( $class->testConf(1) == OK );
     }
     return $class->SUPER::run($r);
 }
@@ -123,16 +138,21 @@ sub run($$) {
 # @param $local boolean
 # @return Apache constant
 sub testConf {
-    my ( $class, $local ) = @_;
+    my ( $class, $local ) = splice @_;
     my $conf = $lmConf->getConf( { local => $local } );
     unless ( ref($conf) ) {
-        $class->lmLog( "$class: Unable to load configuration : $Lemonldap::NG::Common::Conf::msg", 'error' );
+        $class->lmLog(
+"$class: Unable to load configuration: $Lemonldap::NG::Common::Conf::msg",
+            'error'
+        );
         return $cfgNum ? OK : SERVER_ERROR;
     }
-    if ( $cfgNum != $conf->{cfgNum} ) {
-        $class->lmLog( "$class: get configuration ($Lemonldap::NG::Common::Conf::msg)",
-            'debug' );
-    $lastReload = time();
+    if ( !$cfgNum or $cfgNum != $conf->{cfgNum} ) {
+        $class->lmLog(
+"$class: get configuration $conf->{cfgNum} ($Lemonldap::NG::Common::Conf::msg)",
+            'debug'
+        );
+        $lastReload = time();
         return $class->setConf($conf);
     }
     $class->lmLog( "$class: configuration is up to date", 'debug' );
@@ -144,7 +164,7 @@ sub testConf {
 # Local parameters have best precedence on configuration parameters.
 # @return Apache constant
 sub setConf {
-    my ( $class, $conf ) = @_;
+    my ( $class, $conf ) = splice @_;
 
     # Local configuration overrides global configuration
     $cfgNum = $conf->{cfgNum};
@@ -164,7 +184,7 @@ sub setConf {
 # @param $r current request
 # @return Apache constant (OK or SERVER_ERROR)
 sub refresh($$) {
-    my ( $class, $r ) = @_;
+    my ( $class, $r ) = splice @_;
     $class->lmLog( "$class: request for configuration reload", 'notice' );
     $r->handler("perl-script");
     if ( $class->testConf(0) == OK ) {
@@ -200,6 +220,8 @@ __END__
 
 =head1 NAME
 
+=encoding utf8
+
 Lemonldap::NG::Handler::SharedConf - Perl extension to use dynamic
 configuration provide by Lemonldap::NG::Manager.
 
@@ -280,7 +302,7 @@ local store.
 =head1 SEE ALSO
 
 L<Lemonldap::NG::Handler>, L<Lemonldap::NG::Manager>, L<Lemonldap::NG::Portal>,
-http://wiki.lemonldap.objectweb.org/xwiki/bin/view/NG/Presentation
+L<http://lemonldap-ng.org/>
 
 =head1 AUTHOR
 
@@ -289,7 +311,7 @@ Xavier Guimard, E<lt>x.guimard@free.frE<gt>
 =head1 BUG REPORT
 
 Use OW2 system to report bug or ask for features:
-L<http://forge.objectweb.org/tracker/?group_id=274>
+L<http://jira.ow2.org>
 
 =head1 DOWNLOAD
 
@@ -298,10 +320,10 @@ L<http://forge.objectweb.org/project/showfiles.php?group_id=274>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2005-2007 by Xavier Guimard E<lt>x.guimard@free.frE<gt>
+Copyright (C) 2005, 2007, 2010 by Xavier Guimard E<lt>x.guimard@free.frE<gt>
 
 This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.8.4 or,
+it under the same terms as Perl itself, either Perl version 5.10.0 or,
 at your option, any later version of Perl 5 you may have available.
 
 =cut
