@@ -28,7 +28,7 @@ use constant SAFEWRAP => ( Safe->can("wrap_code_ref") ? 1 : 0 );
 #inherits Apache::Session
 #link Lemonldap::NG::Common::Apache::Session::SOAP protected globalStorage
 
-our $VERSION = '1.0.1';
+our $VERSION = '1.1.2';
 
 our %EXPORT_TAGS;
 
@@ -48,7 +48,7 @@ our (
     $customFunctions,    $transform,           $cda,
     $childInitDone,      $httpOnly,            $cookieExpiration,
     $timeoutActivity,    $datasUpdate,         $useRedirectOnForbidden,
-    $useRedirectOnError,
+    $useRedirectOnError, $useSafeJail,
 );
 
 ##########################################
@@ -65,6 +65,7 @@ BEGIN {
               $locationCondition $defaultCondition $locationCount
               $locationProtection $defaultProtection $datasUpdate
               $locationRegexp $apacheRequest $datas safe $customFunctions
+              $useSafeJail
               )
         ],
         import  => [qw( import @EXPORT_OK @EXPORT %EXPORT_TAGS )],
@@ -79,7 +80,7 @@ BEGIN {
             qw( MP OK REDIRECT FORBIDDEN DONE DECLINED SERVER_ERROR
               $useRedirectOnForbidden $useRedirectOnError )
         ],
-        post    => [qw($transform)],
+        post    => [qw($transform postFilter)],
         cda     => ['$cda'],
         cookie  => [qw($cookieName $https $httpOnly $cookieExpiration)],
         session => ['$timeoutActivity'],
@@ -146,6 +147,7 @@ BEGIN {
             threads::shared::share($timeoutActivity);
             threads::shared::share($useRedirectOnForbidden);
             threads::shared::share($useRedirectOnError);
+            threads::shared::share($useSafeJail);
         };
     }
     elsif ( MP() == 1 ) {
@@ -238,20 +240,21 @@ sub regRemoteIp {
     return $str;
 }
 
-## @rfn void lmSetHeaderIn(Apache2::RequestRec r, string h, string v)
+## @rmethod void lmSetHeaderIn(Apache2::RequestRec r, string h, string v)
 # Set an HTTP header in the HTTP request.
 # @param $r Current request
 # @param $h Name of the header
 # @param $v Value of the header
 sub lmSetHeaderIn {
-    my ( $r, %hdr ) = splice @_;
+    my ( $class, $r, %hdr ) = splice @_;
     while ( my ( $h, $v ) = each %hdr ) {
-    if ( MP() == 2 ) {
+        if ( MP() == 2 ) {
             $r->headers_in->set( $h => $v );
-    }
-    elsif ( MP() == 1 ) {
+        }
+        elsif ( MP() == 1 ) {
             $r->header_in( $h => $v );
         }
+        $class->lmLog( "Send header $h with value $v", 'debug' );
     }
 }
 
@@ -315,6 +318,53 @@ sub lmHeaderOut {
     }
 }
 
+##############################
+# Fake Safe jail subroutines #
+##############################
+
+## @method reval
+# Fake reval method if useSafeJail desactivated
+sub reval {
+    my ( $class, $e ) = splice @_;
+    return eval $e;
+}
+
+## @method wrap_code_ref
+# Fake wrap_code_ref method if useSafeJail desactivated
+sub wrap_code_ref {
+    my ( $class, $e ) = splice @_;
+    return $e;
+}
+
+## @method share
+# Fake share method if useSafeJail desactivated
+sub share {
+    my ( $class, @vars ) = splice @_;
+    $class->share_from( scalar(caller), \@vars );
+}
+
+## @method share_form
+# Fake share_from method if useSafeJail desactivated
+sub share_from {
+    my ( $class, $pkg, $vars ) = splice @_;
+
+    no strict 'refs';
+    foreach my $arg (@$vars) {
+        my ( $var, $type );
+        $type = $1 if ( $var = $arg ) =~ s/^(\W)//;
+        for ( 1 .. 2 ) {    # assign twice to avoid any 'used once' warnings
+            *{$var} =
+                ( !$type ) ? \&{ $pkg . "::$var" }
+              : ( $type eq '&' ) ? \&{ $pkg . "::$var" }
+              : ( $type eq '$' ) ? \${ $pkg . "::$var" }
+              : ( $type eq '@' ) ? \@{ $pkg . "::$var" }
+              : ( $type eq '%' ) ? \%{ $pkg . "::$var" }
+              : ( $type eq '*' ) ? *{ $pkg . "::$var" }
+              :                    undef;
+        }
+    }
+}
+
 ##############################
 # Initialization subroutines #
 ##############################
@@ -327,7 +377,8 @@ sub safe {
 
     return $safe if ($safe);
 
-    $safe = new Safe;
+    $useSafeJail = 1 unless defined $useSafeJail;
+
     my @t = $customFunctions ? split( /\s+/, $customFunctions ) : ();
     foreach (@t) {
         $class->lmLog( "Custom function : $_", 'debug' );
@@ -346,7 +397,16 @@ sub safe {
             }";
         $class->lmLog( $@, 'error' ) if ($@);
     }
-    $safe->share_from( 'main', [ '%ENV' ] );
+
+    if ($useSafeJail) {
+        $safe = new Safe;
+        $safe->share_from( 'main', ['%ENV'] );
+    }
+    else {
+        $safe = $class;
+    }
+
+    # Share objets with Safe jail
     $safe->share_from( 'Lemonldap::NG::Common::Safelib',
         $Lemonldap::NG::Common::Safelib::functions );
     $safe->share( '&encode_base64', '$datas', '&portal', '$apacheRequest', @t );
@@ -488,45 +548,49 @@ sub conditionSub {
 
     # Since filter exists only with Apache>=2, logout_app and logout_app_sso
     # targets are available only for it.
-    if ( MP() == 2 ) {
+    # This error can also appear with Manager configured as CGI script
+    if ( $cond =~ /^logout_app/i and MP() < 2 ) {
+        $class->lmLog( "Rules logout_app and logout_app_sso require Apache>=2",
+            'warn' );
+        return ( sub { 1 }, 1 );
+    }
 
-        # logout_app
-        if ( $cond =~ /^logout_app(?:\s+(.*))?$/i ) {
-            my $u = $1 || $class->portal();
-            eval 'use Apache2::Filter' unless ( $INC{"Apache2/Filter.pm"} );
-            return (
-                sub {
-                    $apacheRequest->add_output_filter(
-                        sub {
-                            return $class->redirectFilter( $u, @_ );
-                        }
-                    );
-                    1;
-                },
-                1
-            );
-        }
-        elsif ( $cond =~ /^logout_app_sso(?:\s+(.*))?$/i ) {
-            eval 'use Apache2::Filter' unless ( $INC{"Apache2/Filter.pm"} );
-            my $u = $1 || $class->portal();
-            return (
-                sub {
-                    $class->localUnlog;
-                    $apacheRequest->add_output_filter(
-                        sub {
-                            return $class->redirectFilter(
-                                $class->portal() . "?url="
-                                  . $class->encodeUrl($u)
-                                  . "&logout=1",
-                                @_
-                            );
-                        }
-                    );
-                    1;
-                },
-                1
-            );
-        }
+    # logout_app
+    if ( $cond =~ /^logout_app(?:\s+(.*))?$/i ) {
+        my $u = $1 || $class->portal();
+        eval 'use Apache2::Filter' unless ( $INC{"Apache2/Filter.pm"} );
+        return (
+            sub {
+                $apacheRequest->add_output_filter(
+                    sub {
+                        return $class->redirectFilter( $u, @_ );
+                    }
+                );
+                1;
+            },
+            1
+        );
+    }
+    elsif ( $cond =~ /^logout_app_sso(?:\s+(.*))?$/i ) {
+        eval 'use Apache2::Filter' unless ( $INC{"Apache2/Filter.pm"} );
+        my $u = $1 || $class->portal();
+        return (
+            sub {
+                $class->localUnlog;
+                $apacheRequest->add_output_filter(
+                    sub {
+                        return $class->redirectFilter(
+                            $class->portal() . "?url="
+                              . $class->encodeUrl($u)
+                              . "&logout=1",
+                            @_
+                        );
+                    }
+                );
+                1;
+            },
+            1
+        );
     }
 
     # Replace some strings in condition
@@ -576,6 +640,10 @@ sub defaultValuesInit {
       defined($useRedirectOnForbidden)
       ? $useRedirectOnForbidden
       : $args->{useRedirectOnForbidden};
+    $useSafeJail =
+      defined($useSafeJail)
+      ? $useSafeJail
+      : $args->{useSafeJail};
     1;
 }
 
@@ -709,7 +777,7 @@ sub hideCookie {
     $class->lmLog( "$class: removing cookie", 'debug' );
     my $tmp = lmHeaderIn( $apacheRequest, 'Cookie' );
     $tmp =~ s/$cookieName(?:http)?[^,;]*[,;]?//og;
-    lmSetHeaderIn( $apacheRequest, 'Cookie' => $tmp );
+    $class->lmSetHeaderIn( $apacheRequest, 'Cookie' => $tmp );
 }
 
 ## @rmethod protected string encodeUrl(string url)
@@ -1253,7 +1321,8 @@ qq{<html><body onload="document.getElementById('f').submit()"><form id="f" metho
 ## @rmethod protected void sendHeaders()
 # Launch function compiled by forgeHeadersInit()
 sub sendHeaders {
-    lmSetHeaderIn( $apacheRequest, &$forgeHeaders );
+    my ($class) = splice @_;
+    $class->lmSetHeaderIn( $apacheRequest, &$forgeHeaders );
 }
 
 ## @rmethod protected boolean isProtected()
@@ -1327,40 +1396,47 @@ sub postUrlInit {
             $tmp .= "'$_'=>$postdata{$_},";
         }
 
-        # Build subroutine
-        my $sub = "sub{
-            my \$f = shift;
-            my \$l;
-            unless(\$f->ctx){
-            \$f->ctx(1);
-            my \$u=URI->new('http:');
-            \$u->query_form({$tmp});
-            my \$s=\$u->query();
-            \$l = \$f->r->headers_in->{'Content-Length'};
-            \$f->r->headers_in->set( 'Content-Length' => length(\$s) );
-            \$f->r->headers_in->set( 'Content-Type' => 'application/x-www-form-urlencoded' );
-            \$f->print(\$s);
-            while ( \$f->read( my \$b, \$l ) ) {}
-            \$f->seen_eos(1);
-            }
-            return OK;
-        }"
-          ;
-        $sub = (
-            SAFEWRAP
-            ? $class->safe->wrap_code_ref( $class->safe->reval($sub) )
-            : $class->safe->reval($sub)
-        );
         $class->lmLog( "Compiling POST request for $url", 'debug' );
         $transform->{$url} = sub {
             return $class->buildPostForm($url)
               if ( $apacheRequest->method ne 'POST' );
-            $apacheRequest->add_input_filter($sub);
+            $apacheRequest->add_input_filter(
+                sub {
+                    $class->postFilter( $tmp, @_ );
+                }
+            );
             OK;
           }
     }
 }
 
+## @rmethod protected int postFilter(hashref data, Apache2::Filter f)
+# POST data
+# @param $data Data to POST
+# @param $f Current Apache2::Filter object
+# @return Apache2::Const::OK
+sub postFilter {
+    my $class = shift;
+    my $data  = shift;
+    my $f     = shift;
+    my $l;
+
+    unless ( $f->ctx ) {
+        $f->ctx(1);
+        my $u = URI->new('http:');
+        $u->query_form( { $class->safe->reval($data) } );
+        my $s = $u->query();
+        $l = $f->r->headers_in->{'Content-Length'};
+        $f->r->headers_in->set( 'Content-Length' => length($s) );
+        $f->r->headers_in->set(
+            'Content-Type' => 'application/x-www-form-urlencoded' );
+        $f->print($s);
+        while ( $f->read( my $b, $l ) ) { }
+        $f->seen_eos(1);
+    }
+    return OK;
+}
+
 ## @rmethod protected transformUri(string uri)
 # Transform URI to replay POST forms
 # @param uri URI to catch
@@ -1471,7 +1547,7 @@ sub unlog ($$) {
 # Used by logout_app and logout_app_sso targets
 # @param $url URL to redirect the user
 # @param $f Current Apache2::Filter object
-# @return Apache2::Const::REDIRECT
+# @return Apache2::Const::OK
 sub redirectFilter {
     my $class = shift;
     my $url   = shift;
@@ -1497,7 +1573,7 @@ sub redirectFilter {
         'filter',
         'REDIRECT'
     );
-    return REDIRECT;
+    return OK;
 }
 
 ## @rmethod int status(Apache2::RequestRec $r)
