@@ -11,7 +11,7 @@ use Lemonldap::NG::Portal::AuthLDAP;
 
 use base qw(Lemonldap::NG::Portal::AuthLDAP);
 
-our $VERSION = '0.2';
+our $VERSION = '1.0.0';
 
 ## @apmethod int authInit()
 # Check if SSL environment variables are set.
@@ -38,14 +38,14 @@ sub extractFormInfo {
     my $self = shift;
     my $user = $self->https ? $ENV{ $self->{SSLVar} } : 0;
     if ($user) {
-        $self->{sessionInfo}->{authenticationLevel} = 5;
         $self->{user} = $user;
         $self->{AuthLDAPFilter} ||=
           '(&(' . $self->{SSLLDAPField} . "=$user)(objectClass=inetOrgPerson))";
         return PE_OK;
     }
     elsif ( $self->{SSLRequire} ) {
-        $self->_sub('userError',"No certificate found for $ENV{REMOTE_ADDR}");
+        $self->_sub( 'userError',
+            "No certificate found for $ENV{REMOTE_ADDR}" );
         return PE_CERTIFICATEREQUIRED;
     }
     $self->{AuthLDAPFilter} = '';
@@ -53,7 +53,7 @@ sub extractFormInfo {
 }
 
 ## @apmethod int setAuthSessionInfo()
-# Store user.
+# Set _user and authenticationLevel.
 # @return Lemonldap::NG::Portal constant
 sub setAuthSessionInfo {
     my $self = shift;
@@ -61,6 +61,7 @@ sub setAuthSessionInfo {
     # Store user certificate login for basic rules
     $self->{sessionInfo}->{'_user'} = $self->{'user'};
 
+    $self->{sessionInfo}->{authenticationLevel} = $self->{SSLAuthnLevel};
     PE_OK;
 }
 
@@ -71,18 +72,43 @@ sub setAuthSessionInfo {
 sub authenticate {
     my $self = shift;
     if (    $self->{sessionInfo}->{authenticationLevel}
-        and $self->{sessionInfo}->{authenticationLevel} > 4 )
+        and $self->{sessionInfo}->{authenticationLevel} >=
+        $self->{SSLAuthnLevel} )
     {
         return PE_OK;
     }
     return $self->SUPER::authenticate(@_);
 }
 
+## @apmethod int authFinish()
+# Does nothing.
+# @return Lemonldap::NG::Portal constant
+sub authFinish {
+    PE_OK;
+}
+
+## @apmethod int authLogout()
+# Does nothing
+# @return Lemonldap::NG::Portal constant
+sub authLogout {
+    PE_OK;
+}
+
+## @apmethod boolean authForce()
+# Does nothing
+# @return result
+sub authForce {
+    return 0;
+}
+
 1;
+
 __END__
 
 =head1 NAME
 
+=encoding utf8
+
 Lemonldap::NG::Portal::AuthSSL - Perl extension for building Lemonldap::NG
 compatible portals with SSL authentication.
 
@@ -167,7 +193,7 @@ See L<Lemonldap::NG::Portal::Simple> for usage and other methods.
 =head1 SEE ALSO
 
 L<Lemonldap::NG::Portal>, L<Lemonldap::NG::Portal::Simple>,
-http://wiki.lemonldap.objectweb.org/xwiki/bin/view/NG/Presentation
+L<http://lemonldap-ng.org/>
 
 =head1 AUTHOR
 
@@ -176,7 +202,7 @@ Xavier Guimard, E<lt>x.guimard@free.frE<gt>
 =head1 BUG REPORT
 
 Use OW2 system to report bug or ask for features:
-L<http://forge.objectweb.org/tracker/?group_id=274>
+L<http://jira.ow2.org>
 
 =head1 DOWNLOAD
 
@@ -185,10 +211,10 @@ L<http://forge.objectweb.org/project/showfiles.php?group_id=274>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2005-2007 by Xavier Guimard E<lt>x.guimard@free.frE<gt>
+Copyright (C) 2005, 2007, 2010 by Xavier Guimard E<lt>x.guimard@free.frE<gt>
 
 This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.8.4 or,
+it under the same terms as Perl itself, either Perl version 5.10.0 or,
 at your option, any later version of Perl 5 you may have available.
 
 =cut
