@@ -9,7 +9,7 @@ use strict;
 use Lemonldap::NG::Portal::Simple;
 use utf8;
 
-our $VERSION = '1.0.0';
+our $VERSION = '1.1.2';
 
 ## @method array display()
 # Call portal process and set template parameters
@@ -18,7 +18,7 @@ sub display {
     my $self = shift;
 
     my $skin     = $self->{portalSkin};
-    my $skin_dir = $ENV{DOCUMENT_ROOT} . "/skins";
+    my $skin_dir = $self->getApacheHtdocsPath() . "/skins";
     my ( $skinfile, %templateParams );
     my $http_error = $self->param('lmError');
 
@@ -89,6 +89,7 @@ sub display {
             %templateParams = (
                 AUTH_USER       => $auth_user,
                 AUTOCOMPLETE    => $self->{portalAutocomplete},
+                NEWWINDOW       => $self->{portalOpenLinkInNewWindow},
                 ANTIFRAME       => $self->{portalAntiFrame},
                 SKIN            => $skin,
                 AUTH_ERROR      => $self->error( undef, $self->{menuError} ),
@@ -96,7 +97,9 @@ sub display {
                 DISPLAY_TAB     => $self->{menuDisplayTab},
                 LOGOUT_URL      => "$ENV{SCRIPT_NAME}?logout=1",
                 REQUIRE_OLDPASSWORD => $self->{portalRequireOldPassword},
-                DISPLAY_MODULES     => $self->{menuDisplayModules},
+                HIDE_OLDPASSWORD =>
+                  0,    # Do not hide old password if it is required
+                DISPLAY_MODULES => $self->{menuDisplayModules},
                 APPSLIST_MENU => $self->{menuAppslistMenu},  # For old templates
                 APPSLIST_DESC => $self->{menuAppslistDesc},  # For old templates
                 SCRIPT_NAME   => $ENV{SCRIPT_NAME},
@@ -118,6 +121,8 @@ sub display {
             SKIN            => $skin,
             HIDDEN_INPUTS   => $self->buildHiddenForm(),
             AUTH_URL        => $self->get_url,
+            CHOICE_PARAM    => $self->{authChoiceParam},
+            CHOICE_VALUE    => $self->{_authChoice},
         );
     }
 
@@ -202,36 +207,43 @@ sub display {
         if ( $self->{authLoop} ) {
             %templateParams = (
                 %templateParams,
-                AUTH_LOOP           => $self->{authLoop},
-                CHOICE_PARAM        => $self->{authChoiceParam},
-                CHOICE_VALUE        => $self->{_authChoice},
-                DISPLAY_FORM        => 0,
-                DISPLAY_OPENID_FORM => 0,
+                AUTH_LOOP            => $self->{authLoop},
+                CHOICE_PARAM         => $self->{authChoiceParam},
+                CHOICE_VALUE         => $self->{_authChoice},
+                DISPLAY_FORM         => 0,
+                DISPLAY_OPENID_FORM  => 0,
+                DISPLAY_YUBIKEY_FORM => 0,
             );
         }
 
         # Adapt template if password policy error
         if (
-            $self->{portalDisplayChangePassword}
-            and (  $self->{error} == PE_PP_CHANGE_AFTER_RESET
-                or $self->{error} == PE_PP_MUST_SUPPLY_OLD_PASSWORD
-                or $self->{error} == PE_PP_INSUFFICIENT_PASSWORD_QUALITY
-                or $self->{error} == PE_PP_PASSWORD_TOO_SHORT
-                or $self->{error} == PE_PP_PASSWORD_TOO_YOUNG
-                or $self->{error} == PE_PP_PASSWORD_IN_HISTORY
-                or $self->{error} == PE_PASSWORD_MISMATCH
-                or $self->{error} == PE_BADOLDPASSWORD )
+
+               $self->{error} == PE_PP_CHANGE_AFTER_RESET
+            or $self->{error} == PE_PP_MUST_SUPPLY_OLD_PASSWORD
+            or $self->{error} == PE_PP_INSUFFICIENT_PASSWORD_QUALITY
+            or $self->{error} == PE_PP_PASSWORD_TOO_SHORT
+            or $self->{error} == PE_PP_PASSWORD_TOO_YOUNG
+            or $self->{error} == PE_PP_PASSWORD_IN_HISTORY
+            or $self->{error} == PE_PASSWORD_MISMATCH
+            or $self->{error} == PE_BADOLDPASSWORD
           )
         {
             %templateParams = (
                 %templateParams,
-                REQUIRE_OLDPASSWORD   => 1,
+                REQUIRE_OLDPASSWORD =>
+                  1,    # Old password is required to check user credentials
                 DISPLAY_PASSWORD      => 1,
                 DISPLAY_RESETPASSWORD => 0,
                 DISPLAY_FORM          => 0,
                 AUTH_LOOP             => [],
-                CHOICE_PARAM        => $self->{authChoiceParam},
-                CHOICE_VALUE        => $self->{_authChoice},
+                CHOICE_PARAM          => $self->{authChoiceParam},
+                CHOICE_VALUE          => $self->{_authChoice},
+                OLDPASSWORD =>
+                  $self->checkXSSAttack( 'oldpassword', $self->{oldpassword} )
+                ? ""
+                : $self->{oldpassword},
+                HIDE_OLDPASSWORD => $self->{hideOldPassword},
             );
         }
 
@@ -242,6 +254,19 @@ sub display {
                 DISPLAY_RESETPASSWORD => 0,
                 DISPLAY_FORM          => 0,
                 DISPLAY_OPENID_FORM   => 1,
+                DISPLAY_YUBIKEY_FORM  => 0,
+                AUTH_LOOP             => [],
+            );
+        }
+
+        # Adapt template for Yubikey
+        if ( $self->get_module("auth") =~ /yubikey/i and !$self->{authLoop} ) {
+            %templateParams = (
+                %templateParams,
+                DISPLAY_RESETPASSWORD => 0,
+                DISPLAY_FORM          => 0,
+                DISPLAY_OPENID_FORM   => 0,
+                DISPLAY_YUBIKEY_FORM  => 1,
                 AUTH_LOOP             => [],
             );
         }
@@ -269,6 +294,7 @@ sub display {
             or $self->{error} == PE_OPENID_BADID
             or $self->{error} == PE_MISSINGREQATTR
             or $self->{error} == PE_BADPARTNER
+            or $self->{error} == PE_CAS_SERVICE_NOT_ALLOWED
             or $self->{error} == PE_LOGOUT_OK )
         {
             %templateParams = (
@@ -276,6 +302,7 @@ sub display {
                 DISPLAY_RESETPASSWORD => 0,
                 DISPLAY_FORM          => 0,
                 DISPLAY_OPENID_FORM   => 0,
+                DISPLAY_YUBIKEY_FORM  => 0,
                 AUTH_LOOP             => [],
                 PORTAL_URL            => $self->{portal},
                 MSG                   => $self->info(),
